Document title goes here

# Stallen reinigen en spuiten

Op sectorniveau zijn de belangrijkste knelpunten:

- De lichamelijke belasting bij hogedruk reinigen
- Blootstelling aan gezondheidsschadelijke stoffen en dampen bij toepassen van ontsmettingsmiddel en bij toepassen van bestrijdingsmiddel voor maden- en onkruidbestrijding
- Blootstelling aan mestgassen:
  ammoniak en zwavelwaterstof met gevaar op bedwelming (bij pompen)methaan met risico op ontbranding (ontsteking bijvoorbeeld door las en slijp werkzaamheden).

## Information

This module is mandatory.

## Modules

This module has no submodules. You can add add a submodule.

## Risks

1. Werkzaamheden met de hogedrukspuit worden uitgevoerd.
2. Er kan gebruik worden gemaakt van rechte spuitlansen van verschillende lengte.
3. Voordat er gespoten wordt, wordt het te behandelen oppervlak eerst ingeweekt.
4. Tijdens het werken met bestrijdingsmiddelen wordt altijd gewerkt volgens de aanwijzingen op het etiket.
5. De opslagplaats voor bestrijdingsmiddelen voldoet aan de eisen.
6. De opslagplaats van bestrijdingsmiddelen staat op een strategische plaats, zodat middelen altijd direct weer teruggezet worden.
7. De veiligheidsinformatiebladen (VIB) van bestrijdingsmiddelen, ontsmettingsmiddelen en andere gevaarlijke stoffen zijn direct op de werkplek beschikbaar.
8. De inhoud van de veiligheidsinformatiebladen is besproken met betrokkenen.
9. De ontsmettingsbak (voor laarzen en schoenen) wordt afgesloten met een deksel.
10. De hogedrukreiniger wordt na het gebruik geleegd en/of eindleidingen (van drukleidingsysteem) worden wekelijks doorgespoeld of voor het spuiten doorgespoeld voordat het water wordt verneveld.
11. Bij het gebruik van antibiotica worden altijd handschoenen gedragen.
12. Er is een oogdouche gemonteerd.

- Surveys
- Documentation
- Sectors
- OiRA
- Search

### Survey versions

Survey 2011 (Unpublished)

- Unpublished January 12 2011 Preview Edit

Survey 2010

- Current / Published January 4 2009 Preview Edit

Survey 2009

- Current December 12 2009 Preview Edit
- Published August 5 2009 Preview Edit Update
- March 18 2009 Preview Edit
- February 2 2009 Preview Edit
- January 28 2009 Preview Edit

##### Legend

- Current Version that is currently online
- Current Version you are currently reviewing

Update = This version has changes that are currently unpublished. Click the update icon to bring all the changes live

Draft

Leave retracted Published
Write a revision note.
Notify

Link to sector organisation | Disclaimer | Design by Cornae